autologistic model object.Return the estimated covariance matrix for an autologistic model object.
# S3 method for autologistic
vcov(object, ...)a fitted autologistic model object.
additional arguments.
An estimate of the covariance matrix of the parameters (in a Bayesian setting), or an estimate of the covariance matrix of the maximum pseudolikelihood estimator of the parameters.